==> installer-framework-opensource-src-4.1.1.zip: installer-framework-opensource-src-4.1.1/src/libs/installer/uninstallercalculator.h <==
/**************************************************************************
**
** Copyright (C) 2017 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of the Qt Installer Framework.
**
** $QT_BEGIN_LICENSE:GPL-EXCEPT$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
**************************************************************************/
#ifndef UNINSTALLERCALCULATOR_H
#define UNINSTALLERCALCULATOR_H

#include "installer_global.h"

#include <QHash>
#include <QList>
#include <QSet>
#include <QString>

namespace QInstaller {

class Component;

class INSTALLER_EXPORT UninstallerCalculator
{
public:
    UninstallerCalculator(const QList<Component *> &installedComponents);

    QSet<Component*> componentsToUninstall() const;

    void appendComponentsToUninstall(const QList<Component*> &components);

private:

    void appendComponentToUninstall(Component *component);
    void continueAppendComponentsToUninstall();

    QList<Component *> m_installedComponents;
    QSet<Component *> m_componentsToUninstall;
};

}


#endif // UNINSTALLERCALCULATOR_H

==> installer-framework-opensource-src-4.3.0.zip: installer-framework-opensource-src-4.3.0/src/libs/installer/uninstallercalculator.h <==
/**************************************************************************
**
** Copyright (C) 2022 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of the Qt Installer Framework.
**
** $QT_BEGIN_LICENSE:GPL-EXCEPT$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
**************************************************************************/
#ifndef UNINSTALLERCALCULATOR_H
#define UNINSTALLERCALCULATOR_H

#include "installer_global.h"

#include <QHash>
#include <QList>
#include <QSet>
#include <QString>

namespace QInstaller {

class Component;
class PackageManagerCore;

class INSTALLER_EXPORT UninstallerCalculator
{
public:
    UninstallerCalculator(const QList<Component *> &installedComponents, PackageManagerCore *core);

    QSet<Component*> componentsToUninstall() const;

    void appendComponentsToUninstall(const QList<Component*> &components);

private:

    void appendComponentToUninstall(Component *component);
    void continueAppendComponentsToUninstall();

    QList<Component *> m_installedComponents;
    QSet<Component *> m_componentsToUninstall;
    PackageManagerCore *m_core;
};

}


#endif // UNINSTALLERCALCULATOR_H
